# Ollama-GUI

![GitHub License](https://img.shields.io/github/license/chyok/ollama-gui)

A very simple ollama GUI, implemented using the built-in Python Tkinter library, with no additional dependencies.

![ollama-gui](https://github.com/chyok/ollama-gui/assets/32629225/672ba3c1-f7eb-4ee2-bcff-e06a0a3f349f)

+ one file project.
+ no external dependencies.

## Run
Choose any way you like:
### source code

`python ollama_gui.py`

### using pip

```
pip install ollama-gui
ollama-gui
```

### binary file

| Platform | Download Link | 
|----------|---------------|
| Windows  | TBD           |

## License

This project is licensed under the [MIT License](LICENSE).

